# krazy-utils

I am a beginner in programming and have recently started programming in python. krazy-utils is a simple package containing following functions I use frequently. I just wrote some of them so that I dont forget how to write them ;p

